# R code to reproduce the estimates of proportions and odds ratios and figures reported
# Please note that the forest plots in Figures 2 and 4 are longer than can be visualised using the graphics device in R, and should be saved as an image file in order to view the whole plot

# R version 3.6.1 was downloaded from: https://cran.r-project.org/

# installation of "meta" package 
# (takes less than 10 seconds using PC with 8 GB RAM and Windows 10 operating system)
install.packages("meta")
library(meta)

#####
## Reading in data and summary of variables
#####

# data in Supplementary spreadsheet "COVID Sex Bias Table 25-09-2020.csv"
data <- read.csv("COVID Sex Bias Table 25-09-2020.csv", na.strings=c("-", " -", "- ", " - ", " ", "", "NA"), stringsAsFactors=FALSE)

# dataframe named "data" includes the following variables:
# "Country" (country or region, if regional data used because data on confirmed cases or outcomes broken down by sex not provided at the national level)
# "Reference" (reference number in reference list)
# "Date.Until" (date source accessed)
# "Updated.Numbers.Provided" (variable to indicate whether source provided updated data when all data were updated during course of peer review)
# "Total.Confirmed.Cases" (total cases with a confirmed positive result for SARS-COV-2)
# "Total.Male.Cases" (count for total male confirmed cases where this number provided by source)
# "Cases.M." (percentage of total confirmed cases that were male, this was still recorded if the count of male confirmed cases was not provided by the source for calculating the count)                     
# "Total.Female.Cases" (count for total female confirmed cases where this number provided by source)
# "Cases.F." (percentage of total confirmed cases that were female, this was still recorded if the count of female confirmed cases was not provided by the source for calculating the count)                     
# "Total.ITU.Admissions" (total cases that were admitted to an intensive treatment unit)
# "Total.Male.ITU" (count for total male cases admitted to an ITU where this number provided by source)
# "ITU.M." (percentage of total cases admitted to an ITU that were male, this was still recorded if the count of male ITU admissions was not provided by the source for calculating the count)
# "Total.Female.ITU" (count for total male cases admitted to an ITU where this number provided by source)
# "ITU.F." (percentage of total cases admitted to an ITU that were female, this was still recorded if the count of female ITU admissions was not provided by the source for calculating the count)
# "Total.Deaths" (total deaths due to COVID-19)
# "Total.Male.Deaths" (count for total male cases who died due to COVID-19 where this number provided by source)
# "Deaths.M." (percentage of total cases due to COVID-19 that were male, this was still recorded if the count of male deaths due to COVID-19 was not provided by the source for calculating the count)
# "Total.Female.Deaths" (count for total female cases who died due to COVID-19 where this number provided by source)
# "Deaths.F." (percentage of total cases due to COVID-19 that were female, this was still recorded if the count of female deaths due to COVID-19 was not provided by the source for calculating the count)
# "Source.Link" (link to source used for data)

# pasted "Country", "Date.Until" and "Reference" variables to make new "Source" variable
data$Source <- paste(paste(data$Country, data$Date.Until, sep=", "), paste("(", data$Reference, ")", sep=""), sep=" ")
# remove empty rows with no data in the "Country" variable
data <- data[!is.na(data$Country), ]



#####
## Calculation of male and female counts of confirmed cases from percentages
#####

# calculate counts for male and female infected cases from percentages, round to nearest whole number
data$Cases.M.calc <- round(((data$Cases.M.)/100) * data$Total.Confirmed.Cases, digits=0)
data$Cases.F.calc <- round(((data$Cases.F.)/100) * data$Total.Confirmed.Cases, digits=0)

# make new variables of male and female infected cases
# if counts available in original source use these, otherwise use count calculated from % if % supplied
# if neither count nor % supplied in source, then NA

data$Total.Male.Cases.Updated <- ifelse(!is.na(data$Total.Male.Cases), data$Total.Male.Cases, 
                                        ifelse(!is.na(data$Cases.M.calc), data$Cases.M.calc,
                                               NA
                                        )
)
sum(!is.na(data$Total.Male.Cases)) #data on male infected cases provided by 64 sources
sum(data$Total.Male.Cases==data$Total.Male.Cases.Updated, na.rm=TRUE) #64
sum(!is.na(data$Total.Male.Cases.Updated)) #92
# i.e. the 64 counts supplied by countries are there and an additional 28 calculated counts have been added

data$Total.Female.Cases.Updated <- ifelse(!is.na(data$Total.Female.Cases), data$Total.Female.Cases, 
                                          ifelse(!is.na(data$Cases.F.calc), data$Cases.F.calc,
                                                 NA
                                          )
)

sum(!is.na(data$Total.Female.Cases)) #data on female infected cases provided by 64 sources
sum(data$Total.Female.Cases==data$Total.Female.Cases.Updated, na.rm=TRUE) #64
sum(!is.na(data$Total.Female.Cases.Updated)) #92
# i.e. the 64 counts supplied by countries are there and an additional 28 calculated counts have been added

# make new variable of total cases calculated from the updated totals for males and females
# if total cases supplied by the source, use that
# if total cases not supplied by source, use the calculated total cases

data$Total.Confirmed.Cases.calc <- (data$Total.Male.Cases.Updated + data$Total.Female.Cases.Updated)

data$Total.Confirmed.Cases.Updated <- ifelse(!is.na(data$Total.Confirmed.Cases), data$Total.Confirmed.Cases,
                                             ifelse(!is.na(data$Total.Confirmed.Cases.calc), data$Total.Confirmed.Cases.calc,
                                                    NA
                                             )
)



## No need to calculate male and female counts of ITU admissions from percentages



#####
## Calculation of male and female counts of deaths from percentages
#####

# calculate for male and female deaths from percentages, round to nearest whole number
data$Deaths.M.calc <- round(((data$Deaths.M.)/100) * data$Total.Deaths, digits=0)
data$Deaths.F.calc <- round(((data$Deaths.F.)/100) * data$Total.Deaths, digits=0)

# make new variables of male and female deaths
# if death counts available in original source use these, otherwise use count calculated from % if % supplied
# if neither count nor % supplied in source, then NA

data$Total.Male.Deaths.Updated <- ifelse(!is.na(data$Total.Male.Deaths), data$Total.Male.Deaths, 
                                         ifelse(!is.na(data$Deaths.M.calc), data$Deaths.M.calc,
                                                NA
                                         )
)

sum(!is.na(data$Total.Male.Deaths)) #data on male deaths provided by 56 sources
sum(data$Total.Male.Deaths==data$Total.Male.Deaths.Updated, na.rm=TRUE) #56
sum(!is.na(data$Total.Male.Deaths.Updated)) #71
# i.e. the 56 counts supplied by countries are there and an additional 15 calculated counts have been added

data$Total.Female.Deaths.Updated <- ifelse(!is.na(data$Total.Female.Deaths), data$Total.Female.Deaths, 
                                           ifelse(!is.na(data$Deaths.F.calc), data$Deaths.F.calc,
                                                  NA
                                           )
)

sum(!is.na(data$Total.Female.Deaths)) #data on female deaths provided by 56 sources
sum(data$Total.Female.Deaths==data$Total.Female.Deaths.Updated, na.rm=TRUE) #56
sum(!is.na(data$Total.Female.Deaths.Updated)) #71
# i.e. the 56 counts supplied by countries are there and an additional 15 calculated counts have been added



#####
## Meta-analysis to estimate proportion of male infected individuals
#####

# deletion of possible duplicate studies from China to ensure same individuals not counted twice:
# Sources "China, 24/02/2020 (10)" and "China, 07/02/2020 (11)"
# retain just the cases with complete Total.Male.Cases.Updated (n=92) and Total.Confirmed.Cases.Updated (n=92)

data2 <- data[!(data$Source %in% c("China, 24/02/2020 (10)", "China, 07/02/2020 (11)")), ]
data2 <- data2[!is.na(data2$Total.Male.Cases.Updated), ]
nrow(data2)
# 90 regions in this analysis

sum(data2$Total.Confirmed.Cases.Updated) # 3111714 individuals in analysis
sum(data2$Total.Male.Cases.Updated) #1528218 males in analysis
sum(data2$Total.Female.Cases.Updated) #1566883 females in analysis

# Meta-analysis to estimate proportion of male infections
infect.meta.prop <- metaprop(event=data2$Total.Male.Cases.Updated, n=data2$Total.Confirmed.Cases.Updated, 
                             studlab=data2$Source, null.effect=0.5, method="inverse")

# Generate forest plot
# To save and visualise the whole plot, we recommend saving as a pdf with width=12 and height=20
forest.meta(infect.meta.prop, 
            label.right="Higher proportion of men", 
            leftcols=c("studlab", "event", "n"), 
            leftlabs=c("Source", "Infected Males", "Total Infections"), 
            label.left="Higher proportion of women", 
            rightcols=c("effect", "ci", "w.random"), 
            smlab="Proportion of Male Infections", 
            col.diamond = "grey35", 
            col.study="black", 
            col.inside="black", 
            weight.study="random",
            comb.fixed=FALSE,
            overall.hetstat=FALSE)

# Extract p-value
infect.meta.prop$pval.random
# 0.5616174



#####
## Meta-analysis to estimate odds ratio for ITU admission for male confirmed cases
#####

# restrict analysis to studies with complete data

data3 <- data[!(is.na(data$Total.Male.Cases.Updated)) & !(is.na(data$Total.Male.ITU)), ]
nrow(data3)
# 8 regions included in this analysis

sum(data3$Total.Confirmed.Cases) #341571 confirmed cases included in the analysis
sum(data3$Total.Male.Cases.Updated + data3$Total.Female.Cases.Updated) #341563
sum(data3$Total.Male.Cases.Updated) #148180 male cases included in the analysis
sum(data3$Total.Female.Cases.Updated) #193383 female cases included in the analysis
sum(data3$Total.ITU.Admissions) #12067 ITU admissions
sum(data3$Total.Male.ITU + data3$Total.Female.ITU) #12067
sum(data3$Total.Male.ITU) #8397 male ITU admissions
sum(data3$Total.Female.ITU) #3670 female ITU admissions

# Meta-analysis to estimate odds ratio for association of ITU admission with male sex
itu.meta.or <- metabin(event.e=data3$Total.Male.ITU, n.e=data3$Total.Male.Cases.Updated, 
                       event.c=data3$Total.Female.ITU, n.c=data3$Total.Female.Cases.Updated, 
                       sm="OR", studlab=data3$Source)

# Generate forest plot
# To save and visualise the whole plot, we recommend saving as a pdf with width=12 and height=5
forest.meta(itu.meta.or, 
            lab.e = "Males", 
            lab.c="Females", 
            label.right="Higher risk for men", 
            leftcols=c("studlab", "event.e", "n.e", "event.c", "n.c"), 
            leftlabs=c("Source", "ITU", "Total", "ITU", "Total"), 
            label.left="Higher risk for women", 
            rightcols=c("effect", "ci", "w.random"), 
            smlab="ITU Odds Ratio", 
            col.diamond = "grey35", 
            col.study="black", 
            col.inside="black", 
            weight.study = "random",
            comb.fixed=FALSE,
            overall.hetstat=FALSE)

# Extract p-value
itu.meta.or$pval.random
# 1.856581e-10



#####
## Meta-analysis to estimate odds ratio for mortality for male confirmed cases
#####

# deletion of possible duplicate studies from China to ensure same individuals not counted twice:
# Sources "China, 24/02/2020 (10)" and "China, 07/02/2020 (11)"
# data2 already excludes these within the data.orig dataset, with non-missing Total.Male.Cases.Updated

# restrict analysis to studies with complete data on total male deaths and total male cases: n=71
data4 <- data2[!(is.na(data2$Total.Male.Deaths.Updated)) & !(is.na(data2$Total.Male.Cases.Updated)), ]
nrow(data4)
# 70 regions included in this analysis

sum(data4$Total.Confirmed.Cases.Updated) #2751115 total confirmed cases included in the analysis
sum(data4$Total.Male.Cases.Updated + data4$Total.Female.Cases.Updated) #2735514
sum(data4$Total.Male.Cases.Updated) #1319094 male cases included in the analysis
sum(data4$Total.Female.Cases.Updated) #1416420 female cases included in the analysis
sum(data4$Total.Deaths, na.rm=TRUE) #214361 total deaths included in the analysis
sum(data4$Total.Male.Deaths.Updated + data4$Total.Female.Deaths.Updated) #211448
sum(data4$Total.Male.Deaths.Updated) #120285 male deaths included in the analysis
sum(data4$Total.Female.Deaths.Updated) #91163 female deaths included in the analysis

# Meta-analysis to estimate odds ratio for association of mortality with male sex
mort.meta.or <- metabin(event.e=data4$Total.Male.Deaths.Updated,       n.e=data4$Total.Male.Cases.Updated, 
                        event.c=data4$Total.Female.Deaths.Updated, n.c=data4$Total.Female.Cases.Updated, 
                        sm="OR", studlab=data4$Source)

# Generate forest plot
# To save and visualise the whole plot, we recommend saving as a pdf with width=12 and height=18
forest.meta(mort.meta.or, 
            lab.e = "Males", 
            lab.c="Females", 
            abel.right="Higher risk for men", 
            leftcols=c("studlab", "event.e", "n.e", "event.c", "n.c"), 
            leftlabs=c("Source", "Deaths", "Total", "Deaths", "Total"), 
            label.left="Higher risk for women", rightcols=c("effect", "ci", "w.random"), 
            smlab="Mortality Odds Ratio", 
            col.diamond = "grey35", 
            col.study="black", 
            col.inside="black", 
            weight.study = "random",
            comb.fixed=FALSE,
            overall.hetstat=FALSE)

# Extract p-value
mort.meta.or$pval.random
# 5.003075e-30



#####
## Supplementary sensitivity analysis for proportion of male infections
#####

# Funnel plot for estimated proportion of male infections
funnel(infect.meta.prop, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)

# Test of asymmetry using weighted linear regression method
metabias(infect.meta.prop, method.bias="linreg")
# p=0.5142

# "Trim-and-fill" for sensitivity analysis
tf.infect.meta.prop <- trimfill(infect.meta.prop)

# Output includes random effects estimate and 95% confidence interval
# Note there are 0 added 'studies' so estimates are unchanged
tf.infect.meta.prop
#proportion           95%-CI     z p-value
#Random effects model     0.4953 [0.4793; 0.5112] -0.58  0.5616

# Extraction of exact p-value 
tf.infect.meta.prop$pval.random
# 0.5616174

# Funnel plot for estimated proportion of male infections following "trim-and-fill"
funnel(tf.infect.meta.prop, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)



#####
## Supplementary sensitivity analysis for odds ratio for association of male sex with ITU admission
#####

# Funnel plot for estimated odds ratio
funnel(itu.meta.or, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)

# Test of asymmetry using weighted linear regression method
metabias(itu.meta.or, method.bias="linreg", k.min=7)
# 0.7826

# "Trim-and-fill" for sensitivity analysis
tf.itu.meta.or <- trimfill(itu.meta.or)

# Output includes random effects estimate and 95% confidence interval
# Note there are 2 added 'studies' resulting in different estimates
tf.itu.meta.or
#OR           95%-CI    z  p-value
#Random effects model 3.4601 [2.4297; 4.9276] 6.88 < 0.0001

# Extraction of exact p-value 
tf.itu.meta.or$pval.random
# 5.911577e-12

# Funnel plot for estimated odds ratio following "trim-and-fill"
funnel(tf.itu.meta.or, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)



#####
## Supplementary sensitivity analysis for odds ratio for association of male sex with mortality
#####

# Funnel plot for estimated odds ratio
funnel(mort.meta.or, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)

# Test of asymmetry using weighted linear regression method
metabias(mort.meta.or, method.bias="linreg")
# 0.001346

# "Trim-and-fill" for sensitivity analysis
tf.mort.meta.or <- trimfill(mort.meta.or)

# Output includes random effects estimate and 95% confidence interval
# Note there are 26 added 'studies' resulting in different estimates
tf.mort.meta.or
#OR           95%-CI     z  p-value
#Random effects model 1.6432 [1.5524; 1.7392] 17.13 < 0.0001

# Extraction of exact p-value 
tf.mort.meta.or$pval.random
# 8.785181e-66

# Funnel plot for estimated odds ratio following "trim-and-fill"
funnel(tf.mort.meta.or, 
       comb.fixed=TRUE, 
       comb.random=TRUE, 
       col.fixed="red", 
       col.random="blue",
       cex.axis=1.5,
       cex.lab=1.5,
       cex=2
)


## Whole code takes less than 60 seconds to run
